from django.test import TestCase
from django.core.mail import EmailMultiAlternatives
from saferecipient import EmailBackend


class TestEmailBackend(TestCase):
    def test_safeguard(self):
        with self.settings(SAFE_EMAIL_RECIPIENT='safe@example.com'):
            message = self._setup_message()
            EmailBackend()._safeguard(message)
            self.assertEquals(message.from_email, 'safe@example.com')
            self.assertEquals(message.to, ['safe@example.com'])
            self.assertEquals(message.cc, [])
            self.assertEquals(
                message.attachments[0].get_payload(),
                ("Original From: sender@example.com\nOriginal To: "
                 "['recipient@example.com']\nOriginal CC: "
                 "['cc_recipient@example.com']\nOriginal BCC: []\n"))

    def test_no_setting(self):
        message = self._setup_message()
        self.assertRaises(
            AttributeError, EmailBackend()._safeguard, message)

    def _setup_message(self):
        return EmailMultiAlternatives(
            subject='test', body='TEST', from_email='sender@example.com',
            to=['recipient@example.com'], cc=['cc_recipient@example.com'])



"""SMTP email backend class that only sends email to a safe email address"""

from django.core.mail.backends.smtp import EmailBackend as SMTPEmailBackend
from email.mime.text import MIMEText
from django.conf import settings


class EmailBackend(SMTPEmailBackend):
    """
    Re-routes email, so it goes to, and comes from
    settings.SAFE_EMAIL_RECIPIENT.

    The original to and from are added to a text file
    that is attached to the message.
    """
    def send_messages(self, email_messages):
        for message in email_messages:
            self._safeguard(message)
        return super(EmailBackend, self).send_messages(email_messages)

    def _safeguard(self, message):
        originals = (
            "Original From: %s\nOriginal To: %s\nOriginal CC: %s\n"
            "Original BCC: %s\n") % (
                message.from_email, message.to, message.cc, message.bcc)

        message.from_email = settings.SAFE_EMAIL_RECIPIENT
        message.to = [settings.SAFE_EMAIL_RECIPIENT]
        message.cc = []
        message.bcc = []
        text_attachment = MIMEText(originals)
        text_attachment.add_header(
            'Content-disposition',
            'attachment; filename="original_emails.txt"')
        message.attach(text_attachment)
